.. Copyright (C) 2015-2016 Maciej Delmanowski <drybjed@gmail.com>
.. Copyright (C) 2015      Hartmut Goebel <h.goebel@crazy-compilers.com>
.. Copyright (C) 2015-2019 Robin Schneider <ypid@riseup.net>
.. Copyright (C) 2015-2019 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

.. _debops.owncloud:

debops.owncloud
===============

.. include:: man_description.rst
   :start-line: 9

.. toctree::
   :maxdepth: 2

   getting-started
   external-users
   external-storage
   defaults/main
   defaults-detailed
   ldap-dit

Copyright
---------

.. literalinclude:: ../../../../ansible/roles/owncloud/COPYRIGHT

..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
